bug-gnustep
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Patches to dev-libs/db


From: Kim Shrier
Subject: Patches to dev-libs/db
Date: Fri, 10 Aug 2001 20:41:31 -0500

While experimenting with the dev-libs/db source I ran into some minor
problems.  These patches are against the dev-libs sources from
August 6.

dev-libs-patch1 - this corrects a misspelled word "pricipal" in a
                  comment and in an error message.

dev-libs-patch2 - This adds a definition for MySQL_PRINCIPAL_CLASS
                  in the GNUmakefile for the MySQL adaptor.
                  Without this macro definition, the Info.plist and
                  Info-gnustep.plist files are not generated
                  correctly.

dev-libs-patch3 - This adds a definition for Postgres95_PRINCIPAL_CLASS
                  in the GNUmakefile for the Postgres95 adaptor.
                  Without this macro definition, the Info.plist and
                  Info-gnustep.plist files are not generated
                  correctly.

-- 
 Kim Shrier - principal, Shrier and Deihl - mailto:kim@tinker.com
Remote Unix Network Admin, Security, Internet Software Development
  Tinker Internet Services - Superior FreeBSD-based Web Hosting
                     http://www.tinker.com/
--- dev-libs/db/eoadaptors/MySQL/GNUmakefile.orig       Wed Sep 13 12:41:02 2000
+++ dev-libs/db/eoadaptors/MySQL/GNUmakefile    Thu Aug  9 12:15:10 2001
@@ -32,6 +32,8 @@
 # The bundles to be compiled
 BUNDLE_NAME=MySQL
 
+MySQL_PRINCIPAL_CLASS=MySQLAdaptor
+
 # The bundle Objective-C source files to be compiled
 MySQL_OBJC_FILES = \
 MySQLAdaptor.m \
--- dev-libs/db/eoadaptors/Postgres95/GNUmakefile.orig  Thu Dec 17 10:34:10 1998
+++ dev-libs/db/eoadaptors/Postgres95/GNUmakefile       Thu Aug  9 11:49:49 2001
@@ -32,6 +32,8 @@
 # The bundles to be compiled
 BUNDLE_NAME=Postgres95
 
+Postgres95_PRINCIPAL_CLASS=Postgres95Adaptor
+
 # The bundle Objective-C source files to be compiled
 Postgres95_OBJC_FILES = \
 Postgres95Adaptor.m \

reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- dev-libs/db/eoaccess/EOAdaptor.m.orig       Thu Oct  2 18:34:20 1997
+++ dev-libs/db/eoaccess/EOAdaptor.m    Thu Aug  9 11:31:48 2001
@@ -174,7 +174,7 @@
                initWithFormat:@"Cannot find adaptor bundle '%@'",
                                adaptorName]);
 
     /* Get the adaptor bundle "infoDictionary", and pricipal class, ie. the
        adaptor class. Other info about the adaptor should be put in the
        bundle's "Info.plist" file (property list format - see NSBundle class
        documentation for details about reserved keys in this dictionary
@@ -185,7 +185,7 @@
     if(!adaptorClass)
        THROW([[InvalidAdaptorBundleException alloc]
                    initWithFormat:@"The adaptor bundle '%@' doesn't contain "
-                                  @"a pricipal class", adaptorName]);
+                                  @"a principal class", adaptorName]);
     return [[[adaptorClass alloc] initWithName:adaptorName] autorelease];
 }
 
@@ -174,7 +174,7 @@
                                adaptorName]);
 
-    /* Get the adaptor bundle "infoDictionary", and pricipal class, ie. the
+    /* Get the adaptor bundle "infoDictionary", and principal class, ie. the
        adaptor class. Other info about the adaptor should be put in the
        bundle's "Info.plist" file (property list format - see NSBundle class